Django Forms - durian.forms — durian v0.0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.1 documentation »
- Module API Reference »

# Django Forms - durian.forms

`durian.forms.` `create_select_hook_form`(*args, **kwargs)
  Dynamically create a form that has a `ChoiceField` listing all the hook types registered in the hook registry.

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.1 documentation »
- Module API Reference »